#
# spec file for package rapidcsv
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rapidcsv
Version:        8.84
Release:        1.1
Summary:        C++ header-only library for CSV parsing
License:        BSD-3-Clause
URL:            https://github.com/d99kris/rapidcsv
Source:         https://github.com/d99kris/rapidcsv/archive/refs/tags/v%{version}/rapidcsv-%{version}.tar.gz
Group:          Development/Libraries/C and C++
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  make

%description
Rapidcsv is a C++ header-only library for CSV parsing.
It targets rapid development rather than rapid parsing.

%package devel
Summary:        C++ header-only library for CSV parsing
Group:          Development/Languages/C and C++
BuildArch:      noarch

%description devel
Rapidcsv is a C++ header-only library for CSV parsing.
It targets rapid development rather than rapid parsing.

%prep
%autosetup -p1

%build
# This is a header-only library, we don't build anything but unit-tests
%cmake -DCMAKE_BUILD_TYPE=Debug -DRAPIDCSV_BUILD_TESTS:BOOL=On
%cmake_build

%install
%cmake_install

find examples -perm 0755 -and -type f -exec chmod 0644 {} +
mkdir -p %{buildroot}/%{_docdir}/%{name}-devel
cp -rp examples %{buildroot}/%{_docdir}/%{name}-devel/examples

%fdupes %{buildroot}/%{_prefix}

%check
%ctest

%files devel
%license LICENSE
%doc README.md doc
%{_includedir}/rapidcsv.h
%{_docdir}/%{name}-devel/examples

%changelog
* Sat Sep 28 2024 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to version 8.84:
  * handle trailing empty cell without linebreak
* Sat Jun 22 2024 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to version 8.83:
  * fixes #161 - writing CSV with autoquote enabled should quote strings
    containing linebreak
* Sat Mar 23 2024 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to version 8.82:
  * handle trailing comment line without linebreak
  * fix for whitespaced quoted separators
* Fri Jan  5 2024 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to version 8.80:
  * fix default arguments for SeparatorParams constructor in
    documentation
  * fix build error with GCC 4.8.5
  * enable ccache only when tests are enabled
  * optional ccache
  * fix build warnings on openSUSE 15.4 / g++ v7.5.0
- Drop 0001-Include-cpp-limits-header.patch: upstreamed
- Changes since 8.77:
  * add two SetCell methods for consistency with GetCell
  * switch ssize_t usage to int
- Changes since 8.75:
  * retain UTF-8 BOM on Save
  * ensure setting cell value works correctly with column headers
    offset
  * ignore c++ locale when mNumericLocale is set false
  * fix precision loss when writing floating-point values to csv
    document
  * fix no_converter::what() accessability
  * update doc mentioning package managers vcpkg and conan
  * add missing "const" qualifier to several functions in class
    Document
- Changes since 8.69:
  * update issue templates, ci branches and gitignore
  * use cmake --build for windows build
  * add utf-8 flag for windows build
  * compliance with effective c++ guidelines
  * add support for custom quote character
  * Include limits header
  * update doc
- Changes since 8.65:
  * fix sign conversion warnings
* Tue Nov  1 2022 Jan Engelhardt <jengelh@inai.de>
- Compact description. Use find's "+" mode during build.
* Thu Oct 27 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Initial version
